import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import d3, { scaleSqrt, max} from 'd3';
import { useWorldAtlas } from './useWorldAtlas';
import { Marks } from './Marks';
import { useCities } from './useCities';

const width = 960;
const height = 500;

const App = () => {
  const worldAtlas = useWorldAtlas();
  const cities = useCities();

  if (!worldAtlas || !cities) {
    return <pre>Loading...</pre>;
  }

  const sizeValue = d => d.population;
  const maxRadius = 10;
  
  const sizeScale = scaleSqrt()
  	.domain([0, max(cities, sizeValue)])
  	.range([0, maxRadius]);
  console.log(sizeValue);
  
  return (
    <svg width={width} height={height}>
        <Marks 
          worldAtlas={worldAtlas}
          cities={cities}
          sizeValue={sizeValue}
          sizeScale={sizeScale}
          />
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
